@@ -1,16 +1,26 @@
-/* 
+/*
  * Copyright (C) 2007 Tommi Maekitalo, Mark Wright
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -23,6 +33,7 @@
 #include <iostream>
 #include <sstream>
 #include <stdexcept>
+#include <stdint.h>
 
 namespace tntdb
 {
@@ -86,7 +97,7 @@ namespace tntdb
     /// @param man integer decimal mantissa value to set this Decimal number to.
     /// @param exp integer base 10 exponent to set this Decimal number to.
     Decimal(int64_t man, ExponentType exp);
-    
+
     /// Initializes the Decimal-object with the given MantissaType mantissa
     /// and ExponentType exponent
     /// @param man integer decimal mantissa value to set this Decimal number to.
@@ -112,7 +123,7 @@ namespace tntdb
     bool isInfinity() const;
 
     /// Is this Decimal number positive or negative infinity?
-    /// @param positiveInfinity 
+    /// @param positiveInfinity
     /// @return If postitiveInfinity is true, then return true if this
     /// Decimal number is postitive infinity.
     /// Else if postitiveInfinity is false, then return true if this
@@ -128,7 +139,7 @@ namespace tntdb
     /// Is this Decimal number zero?
     /// @return true if this Number object is zero, else return false.
     bool isZero() const;
-      
+
     /// Split this decimal number into integral part, fractional
     /// and exponent parts.  An optional user specified exponent
     /// offset can be used to first scale the decimal number.
@@ -147,9 +158,9 @@ namespace tntdb
                                        ExponentType optionalUserSpecifiedExponentOffset = 0) const throw(std::overflow_error);
 
     /// Return the number of decimal digits in n.
-    template <typename IntegerType> 
+    template <typename IntegerType>
     IntegerType numberOfDigits(IntegerType n) const;
-    
+
     /// Return this number as a C++ integer type.
     /// @param roundingAlgorithm @link Decimal::RoundingAlgorithmType @endlink
     /// @return integer result if the result will fit.
@@ -169,18 +180,30 @@ namespace tntdb
     int getInt() const throw(std::overflow_error)
       { return getInteger<int>(); }
 
+    /// Return this decimal number rounded as a C++ long.
+    /// @return long result if the result will fit.
+    /// @throw std::overflow_error if the result will not fit
+    long getLong() const throw(std::overflow_error)
+      { return getInteger<long>(); }
+
     /// Return this decimal number rounded as a C++ int32_t.
     /// @return int32_t result if the result will fit.
     /// @throw std::overflow_error if the result will not fit
     int32_t getInt32() const throw(std::overflow_error)
       { return getInteger<int32_t>(); }
-      
+
     /// Return this decimal number rounded as a C++ unsigned.
     /// @return unsigned result if the result will fit.
     /// @throw std::overflow_error if the result will not fit
     unsigned getUnsigned() const throw(std::overflow_error)
       { return getInteger<unsigned>(); }
 
+    /// Return this decimal number rounded as a C++ unsigned long.
+    /// @return unsigned long result if the result will fit.
+    /// @throw std::overflow_error if the result will not fit
+    unsigned long getUnsignedLong() const throw(std::overflow_error)
+      { return getInteger<unsigned long>(); }
+
     /// Return this decimal number rounded as a C++ uint32_t.
     /// @return uint32_t result if the result will fit.
     /// @throw std::overflow_error if the result will not fit
@@ -198,7 +221,7 @@ namespace tntdb
     /// @throw std::overflow_error if the result will not fit
     uint64_t getUnsigned64() const throw(std::overflow_error)
       { return getInteger<uint64_t>(); }
-    
+
     /// Convert to a C++ float.
     /// @return float result, which is computed with binary floating point
     /// arithmetic, and hence is an approximation.
@@ -222,29 +245,39 @@ namespace tntdb
     /// @param num floating point value to set this Decimal number to.
     template <typename FloatingPointType>
     void setFloatingPoint(FloatingPointType num);
-    
+
     /// Set this this tntdb::Decimal object to the value of the given
     /// integer type mantissa and base 10 exponent.
     /// @param num integer decimal mantissa value to set this Decimal number to.
     /// @param exponent integer base 10 exponent to set this Decimal number to.
     template <typename IntegerType>
     void setDecimalInteger(IntegerType num, int32_t exponent);
-      
+
     /// Set this this tntdb::Decimal object to the value of the given int.
     /// @param num integer value to set this Decimal number to.
     void setInt(int num)
       { setInteger<int>(num); }
 
+    /// Set this this tntdb::Decimal object to the value of the given long.
+    /// @param num integer value to set this Decimal number to.
+    void setLong(long num)
+      { setInteger<long>(num); }
+
     /// Set this this tntdb::Decimal object to the value of the given int32_t.
     /// @param num integer value to set this Decimal number to.
     void setInt32(int32_t num)
       { setInteger<int32_t>(num); }
-      
+
     /// Set this this tntdb::Decimal object to the value of the given unsigned.
     /// @param num integer value to set this Decimal number to.
     void setUnsigned(unsigned num)
       { setInteger<unsigned>(num); }
 
+    /// Set this this tntdb::Decimal object to the value of the given unsigned.
+    /// @param num integer value to set this Decimal number to.
+    void setUnsignedLong(unsigned long num)
+      { setInteger<unsigned long>(num); }
+
     /// Set this this tntdb::Decimal object to the value of the given uint32_t.
     /// @param num integer value to set this Decimal number to.
     void setUnsigned32(uint32_t num)
@@ -287,7 +320,7 @@ namespace tntdb
     /// Return this Decimal number as a string.
     /// @return string representation of this decimal number.
     std::string toString() const;
-      
+
     /// Print this Decimal number.  If out.precision() != 0, then this
     /// decimal number is printed with out.precision() significant digits.
     /// @param out output stream
@@ -299,7 +332,7 @@ namespace tntdb
     /// @param printFlags the optional printFlags only affect
     /// how positive and negative infinity are printed.
     std::ostream &print(std::ostream &out, PrintFlagsType printFlags) const;
-    
+
     /// Read a Decimal number.
     /// @param in input stream
     /// @param ignoreOverflowReadingFraction if true, ignore overflow errors
@@ -313,7 +346,7 @@ namespace tntdb
     /// read(ostr.str(), true);
     std::istream &read(std::istream &in, bool ignoreOverflowReadingFraction = false);
 
-    ///@name Low level arithmetic methods 
+    ///@name Low level arithmetic methods
     //\@{
     /// Multiply an integer type by 10, checking for overflow.
     /// @param n on input: the number to multply by 10, on output, the
@@ -336,7 +369,26 @@ namespace tntdb
                                    ManType &remainder,
                                    ManType divisorPowerOfTenDigits) throw(std::overflow_error);
     //\@}
-  protected:    
+
+    void normalize();
+
+    bool operator== (const tntdb::Decimal& other) const;
+
+    bool operator!= (const tntdb::Decimal& other) const
+    { return !(*this == other); }
+
+    bool operator< (const tntdb::Decimal& other) const;
+
+    bool operator> (const tntdb::Decimal& other) const
+    { return other < *this; }
+
+    bool operator<= (const tntdb::Decimal& other) const
+    { return !(other < *this); }
+
+    bool operator>= (const tntdb::Decimal& other) const
+    { return !(*this < other); }
+
+  protected:
     ///@internal
     //\@{
     /// Initialize this Decimal number, called by the constructors.
@@ -352,7 +404,7 @@ namespace tntdb
                               MantissaType fractional);
     //\@}
   };
-  
+
   template <typename T>
   bool Decimal::overflowDetectedInMultiplyByTen(T &n)
   {
@@ -370,7 +422,7 @@ namespace tntdb
     return overflowDetected;
   }
 
-  template <typename IntegerType> 
+  template <typename IntegerType>
   IntegerType Decimal::numberOfDigits(IntegerType n) const
   {
     IntegerType multiplier = IntegerType(Base);
@@ -385,7 +437,7 @@ namespace tntdb
     }
     return noDigits;
   }
-  
+
   template <typename ManType>
   void Decimal::divideByPowerOfTen(const ManType dividend,
                                    ManType &quotient,
@@ -454,7 +506,7 @@ namespace tntdb
     quotient = ManType(dividend) / exponentDivisor;
     remainder = ManType(dividend) % exponentDivisor;
   }
-  
+
   template <typename ManType>
   void Decimal::getIntegralFractionalExponent(ManType &integral,
                                               ManType &fractional,
@@ -507,7 +559,7 @@ namespace tntdb
     fractional = ManType(fractionalPart);
     ex = exp;
   }
-  
+
   template <typename IntegerType>
   IntegerType Decimal::getInteger(RoundingAlgorithmType roundingAlgorithm) const throw(std::overflow_error)
   {
@@ -593,7 +645,7 @@ namespace tntdb
       }
     }
   }
-    
+
   template <typename IntegerType>
   void Decimal::setInteger(IntegerType num)
   {
@@ -627,7 +679,7 @@ namespace tntdb
     std::istringstream istr(numStr);
     read(istr, true);
   }
-  
+
   /// Print this Decimal number.  If out.precision() != 0, then this
   /// decimal number is printed with out.precision() significant digits.
   std::ostream &operator<<(std::ostream &out, const Decimal& decimal);
