@@ -1,16 +1,26 @@
-/* 
+/*
  * Copyright (C) 2005 Tommi Maekitalo
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -21,6 +31,7 @@
 #include <cctype>
 #include <sys/time.h>
 #include <time.h>
+#include <string.h>
 
 namespace tntdb
 {
@@ -48,11 +59,14 @@ namespace tntdb
 
   unsigned short Date::getWDay() const
   {
-    struct timeval tv;
     struct tm tm;
+    memset(&tm, 0, sizeof(struct tm));
+    tm.tm_mday = day;
+    tm.tm_mon = month - 1;
+    tm.tm_year = year - 1900;
 
-    gettimeofday(&tv, 0);
-    gmtime_r(&tv.tv_sec, &tm);
+    time_t t = mktime(&tm);
+    localtime_r(&t, &tm);
 
     return tm.tm_wday;
   }
@@ -83,8 +97,8 @@ namespace tntdb
 
   inline unsigned short getNumber2(const char* s)
   {
-    if (!isdigit(s[0])
-      || !isdigit(s[1]))
+    if (!std::isdigit(s[0])
+      || !std::isdigit(s[1]))
       throw TypeError();
     return (s[0] - '0') * 10
          + (s[1] - '0');
@@ -92,10 +106,10 @@ namespace tntdb
 
   inline unsigned short getNumber4(const char* s)
   {
-    if (!isdigit(s[0])
-      || !isdigit(s[1])
-      || !isdigit(s[2])
-      || !isdigit(s[3]))
+    if (!std::isdigit(s[0])
+      || !std::isdigit(s[1])
+      || !std::isdigit(s[2])
+      || !std::isdigit(s[3]))
       throw TypeError();
     return (s[0] - '0') * 1000
          + (s[1] - '0') * 100
