@@ -1,16 +1,26 @@
-/* 
+/*
  * Copyright (C) 2005 Tommi Maekitalo
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -258,12 +268,24 @@ namespace tntdb
       bind.is_unsigned = 0;
     }
 
+    void setLong(MYSQL_BIND& bind, long data)
+    {
+      setValue(bind, data, MYSQL_TYPE_LONG);
+      bind.is_unsigned = 0;
+    }
+
     void setUnsigned(MYSQL_BIND& bind, unsigned data)
     {
       setValue(bind, data, MYSQL_TYPE_LONG);
       bind.is_unsigned = 1;
     }
 
+    void setUnsignedLong(MYSQL_BIND& bind, unsigned long data)
+    {
+      setValue(bind, data, MYSQL_TYPE_LONG);
+      bind.is_unsigned = 1;
+    }
+
     void setInt32(MYSQL_BIND& bind, int32_t data)
     {
       setValue(bind, data, MYSQL_TYPE_LONG);
@@ -413,14 +435,19 @@ namespace tntdb
       return getInteger<int>(bind);
     }
 
+    long getLong(const MYSQL_BIND& bind)
+    {
+      return getInteger<long>(bind);
+    }
+
     unsigned getUnsigned(const MYSQL_BIND& bind)
     {
       return getInteger<unsigned>(bind);
     }
 
-    long getLong(const MYSQL_BIND& bind)
+    unsigned long getUnsignedLong(const MYSQL_BIND& bind)
     {
-      return getInteger<long>(bind);
+      return getInteger<unsigned long>(bind);
     }
 
     int32_t getInt32(const MYSQL_BIND& bind)
