@@ -1,16 +1,26 @@
-/* 
+/*
  * Copyright (C) 2005 Tommi Maekitalo
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -197,6 +207,22 @@ namespace tntdb
         log_warn("hostvar \"" << col << "\" not found");
     }
 
+    void Statement::setLong(const std::string& col, long data)
+    {
+      log_debug("statement " << stmt << " setLong(\"" << col << "\", " << data << ')');
+
+      bool found = false;
+      for (hostvarMapType::const_iterator it = hostvarMap.find(col);
+           it != hostvarMap.end() && it->first == col; ++it)
+      {
+        found = true;
+        inVars.setLong(it->second, data);
+      }
+
+      if (!found)
+        log_warn("hostvar \"" << col << "\" not found");
+    }
+
     void Statement::setUnsigned(const std::string& col, unsigned data)
     {
       log_debug("statement " << stmt << " setUnsigned(\"" << col << "\", " << data << ')');
@@ -213,6 +239,22 @@ namespace tntdb
         log_warn("hostvar \"" << col << "\" not found");
     }
 
+    void Statement::setUnsignedLong(const std::string& col, unsigned long data)
+    {
+      log_debug("statement " << stmt << " setUnsignedLong(\"" << col << "\", " << data << ')');
+
+      bool found = false;
+      for (hostvarMapType::const_iterator it = hostvarMap.find(col);
+           it != hostvarMap.end() && it->first == col; ++it)
+      {
+        found = true;
+        inVars.setUnsignedLong(it->second, data);
+      }
+
+      if (!found)
+        log_warn("hostvar \"" << col << "\" not found");
+    }
+
     void Statement::setInt32(const std::string& col, int32_t data)
     {
       log_debug("statement " << stmt << " setInt32(\"" << col << "\", " << data << ')');
@@ -435,7 +477,7 @@ namespace tntdb
       {
         // use statement-API
         stmt = getStmt();
-        execute(stmt);
+        execute(stmt, 16);
         return mysql_stmt_affected_rows(stmt);
       }
     }
@@ -448,13 +490,14 @@ namespace tntdb
         return conn.select(query);
 
       stmt = getStmt();
-      execute(stmt);
+      execute(stmt, 16);
 
       if (mysql_stmt_store_result(stmt) != 0)
         throw MysqlStmtError("mysql_stmt_store_result", stmt);
 
       MYSQL_FIELD* fields = getFields();
       unsigned field_count = getFieldCount();
+      freeMetadata();
 
       RowContainer* result = new RowContainer();
       cxxtools::SmartPtr<RowContainer> sresult = result;
@@ -474,13 +517,14 @@ namespace tntdb
         return conn.selectRow(query);
 
       stmt = getStmt();
-      execute(stmt);
+      execute(stmt, 1);
 
       if (mysql_stmt_store_result(stmt) != 0)
         throw MysqlStmtError("mysql_stmt_store_result", stmt);
 
       MYSQL_FIELD* fields = getFields();
       unsigned field_count = getFieldCount();
+      freeMetadata();
 
       cxxtools::SmartPtr<IRow> ptr = fetchRow(fields, field_count);
 
@@ -502,7 +546,7 @@ namespace tntdb
 
     ICursor* Statement::createCursor(unsigned fetchsize)
     {
-      return new Cursor(this);
+      return new Cursor(this, fetchsize);
     }
 
     MYSQL_STMT* Statement::getStmt()
@@ -534,33 +578,20 @@ namespace tntdb
         throw e;
       }
 
-// we have currently no test for these STMT_ATTR_..., but that might change:
-
-#ifdef HAVE_STMT_ATTR_CURSOR_TYPE
+/*
       // read always with cursor
-      log_debug("mysql_stmt_attr_set(STMT_ATTR_CURSOR_TYPE)");
+      log_debug("mysql_stmt_attr_set(" << ret << ", STMT_ATTR_CURSOR_TYPE)");
       unsigned long cursorType = CURSOR_TYPE_READ_ONLY;
-      if (mysql_stmt_attr_set(stmt, STMT_ATTR_CURSOR_TYPE, &cursorType) != 0)
+      if (mysql_stmt_attr_set(ret, STMT_ATTR_CURSOR_TYPE, &cursorType) != 0)
       {
-        MysqlStmtError e("mysql_stmt_attr_set", ret);
-        log_debug("mysql_stmt_close(" << ret << ')');
-        ::mysql_stmt_close(ret);
-        throw e;
-      }
-#endif
+        log_debug("error");
 
-#ifdef HAVE_STMT_ATTR_PREFETCH_ROWS
-      // fetch 100 rows at once
-      log_debug("mysql_stmt_attr_set(STMT_ATTR_PREFETCH_ROWS, 100)");
-      unsigned long count = 100;
-      if (mysql_stmt_attr_set(stmt, STMT_ATTR_PREFETCH_ROWS, &count) != 0)
-      {
         MysqlStmtError e("mysql_stmt_attr_set", ret);
         log_debug("mysql_stmt_close(" << ret << ')');
         ::mysql_stmt_close(ret);
         throw e;
       }
-#endif
+*/
 
       // check parametercount
       log_debug("mysql_stmt_param_count(" << ret << ')');
@@ -580,8 +611,14 @@ namespace tntdb
       return ret;
     }
 
-    void Statement::execute(MYSQL_STMT* stmt)
+    void Statement::execute(MYSQL_STMT* stmt, unsigned fetchsize)
     {
+      // fetch multiple rows at once
+      log_debug("mysql_stmt_attr_set(STMT_ATTR_PREFETCH_ROWS, " << fetchsize << ")");
+      unsigned long count = fetchsize;
+      if (mysql_stmt_attr_set(stmt, STMT_ATTR_PREFETCH_ROWS, &count) != 0)
+        throw MysqlStmtError("mysql_stmt_attr_set", stmt);
+
       // bind parameters
       log_debug("mysql_stmt_bind_param(" << stmt << ')');
       if (mysql_stmt_bind_param(stmt, inVars.getMysqlBind()) != 0)
