@@ -1,16 +1,26 @@
-/* 
+/*
  * Copyright (C) 2005 Tommi Maekitalo
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -58,11 +68,21 @@ namespace tntdb
       return getValue<int>(getString(), "int");
     }
 
+    long ResultValue::getLong() const
+    {
+      return getValue<long>(getString(), "long");
+    }
+
     unsigned ResultValue::getUnsigned() const
     {
       return getValue<unsigned>(getString(), "unsigned");
     }
-    
+
+    unsigned long ResultValue::getUnsignedLong() const
+    {
+      return getValue<unsigned>(getString(), "unsigned long");
+    }
+
     int32_t ResultValue::getInt32() const
     {
       return getValue<int32_t>(getString(), "int32_t");
@@ -116,6 +136,8 @@ namespace tntdb
 
     void ResultValue::getString(std::string& ret) const
     {
+      if (PQgetisnull(getPGresult(), row->getRowNumber(), tup_num))
+        throw NullValue();
       char* value = PQgetvalue(getPGresult(), row->getRowNumber(), tup_num);
       int len = PQgetlength(getPGresult(), row->getRowNumber(), tup_num);
       ret.assign(value, len);
@@ -175,11 +197,16 @@ namespace tntdb
     {
       std::string value = PQgetvalue(getPGresult(), row->getRowNumber(), tup_num);
       char ch;
-      unsigned short hour, min, sec;
+      unsigned short hour, min, sec, msec;
+      float fsec;
       std::istringstream in(value);
-      in >> hour >> ch >> min >> ch >> sec;
+      in >> hour >> ch >> min >> ch >> fsec;
       if (in)
-        return Time(hour, min, sec);
+      {
+        sec = static_cast<unsigned short>(fsec);
+        msec = (fsec - sec + .0005) * 1000;
+        return Time(hour, min, sec, msec);
+      }
 
       std::ostringstream msg;
       msg << "can't convert \"" << value << "\" to Time";
@@ -189,19 +216,25 @@ namespace tntdb
     Datetime ResultValue::getDatetime() const
     {
       std::string value = PQgetvalue(getPGresult(), row->getRowNumber(), tup_num);
+      log_debug("datetime value=" << value);
       if (value.find('-') != std::string::npos)
       {
         // ISO 8601/SQL standard
         char ch;
-        unsigned short year, month, day, hour, min, sec;
+        unsigned short year, month, day, hour, min, sec, msec;
+        float fsec;
         std::istringstream in(value);
-        in >> year >> ch >> month >> ch >> day >> hour >> ch >> min >> ch >> sec;
+        in >> year >> ch >> month >> ch >> day >> hour >> ch >> min >> ch >> fsec;
         if (in)
-          return Datetime(year, month, day, hour, min, sec);
+        {
+          sec = static_cast<unsigned short>(fsec);
+          msec = (fsec - sec + .0005) * 1000;
+          return Datetime(year, month, day, hour, min, sec, msec);
+        }
       }
       else if (value.find('/') != std::string::npos)
       {
-        // tradition style
+        // traditional style
         char ch;
         unsigned short year, month, day, hour, min, sec;
         std::istringstream in(value);
