@@ -1,16 +1,26 @@
-/* 
+/*
  * Copyright (C) 2005 Tommi Maekitalo
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -63,11 +73,21 @@ namespace tntdb
 
     void Connection::commitTransaction()
     {
+      // Statement handles are invalidated at transaction end, therefore we
+      // release all cached statements here.
+      // The problem still remains since the application might preserve a
+      // statement handle, which can't be released here.
+      clearStatementCache();
       execute("COMMIT TRANSACTION");
     }
 
     void Connection::rollbackTransaction()
     {
+      // Statement handles are invalidated at transaction end, therefore we
+      // release all cached statements here.
+      // The problem still remains since the application might preserve a
+      // statement handle, which can't be released here.
+      clearStatementCache();
       execute("ROLLBACK TRANSACTION");
     }
 
@@ -112,5 +132,10 @@ namespace tntdb
     {
       return db != 0;
     }
+
+    long Connection::lastInsertId(const std::string& name)
+    {
+      return static_cast<int>(sqlite3_last_insert_rowid(db));
+    }
   }
 }
